@@ -45,7 +45,8 @@ def test_snapshot_matches_runtime(snapshot, biskotaki_ci_project, test_root):
 
     # current CI runs tox -e dev, sdist, and wheel meaning it is certain __pycache__ will be created
     # remove all __pycache__ folders and everything nested under them
-    # this is a tiny bit of a hack, but it is the simplest way to fix the problem
+
+    # for example it is very common for a cpython interpreter to create __pycache__ folders
 
     # for all relative paths, if 'part' __pycache__ is in the path, remove it
     snap_relative_paths_set = set(
@@ -57,10 +58,7 @@ def test_snapshot_matches_runtime(snapshot, biskotaki_ci_project, test_root):
 
     # EXCLUDE artifacts, and cache potentially produced if running linters
     snap_relative_paths_set = set(
-        [x for x in snap_relative_paths_set if '.ruff_cached' not in x.parts]
-    )
-    runtime_relative_paths_set = set(
-        [x for x in runtime_relative_paths_set if '.ruff_cached' not in x.parts]
+        [x for x in snap_relative_paths_set if '.ruff_cache' not in x.parts]
     )
 
     # EXCLUDE from test .pytest_cache/ folders too
